@@ -1,7 +1,22 @@
 from flask.ext.admin.model.form import converts
 from flask.ext.admin.contrib.sqla.form import AdminModelConverter as Converter
 
-from sqla_utils_types import arrow_type, password_type, choice_type, color_type
+try:
+    from sqla_utils_types import arrow_type
+except ImportError:
+    arrow_type = None
+try:
+    from sqla_utils_types import password_type
+except ImportError:
+    password_type = None
+try:
+    from sqla_utils_types import choice_type
+except ImportError:
+    choice_type = None
+try:
+    from sqla_utils_types import color_type
+except ImportError:
+    color_type = None
 
 
 class AdminModelConverter(Converter):
